@@ -17,7 +17,7 @@ limitations under the License.
 """
 
 import falcon
-import mock
+from unittest import mock
 
 from oslo_serialization import jsonutils as json
 
