@@ -19,8 +19,8 @@ limitations under the License.
 import random
 
 import falcon
-import mock
-from mock import patch
+from unittest import mock
+from unittest.mock import patch
 
 from oslo_serialization import jsonutils as json
 
